local json = require("json")
local utils = require("utils")
local utils_device = require("utils_device")
local pl_pretty = require("pl.pretty")
local resty_string = require("resty.string")
local upload = require("resty.upload")
local Set = require("set")
local resty_md5 = require("resty.md5")
local pl_path = require("pl.path")

local request_method = ngx.var.request_method

utils.check_login()
utils.check_permission("GatewayManage")

local function check_param(args)

    local request = args["request"]
    if (request == nil) then
        utils.error_exit(400, "request is invalid")
    end

    local apiVer = request["apiVer"] 
    if (apiVer ~= "0.6") then
        utils.error_exit(400, "apiVer is invalid")
    end
    
    local params = args["params"]
    if(nil == params) then
        utils.error_exit(400, "params should not be null")
    end
   
    local fileName = params["FileName"]
    local fileMd5 = params["FileMd5"]

    if(nil == fileName) then
        utils.error_exit(400, "fileName should not be null")
    end
 
    if(nil == fileMd5) then
        utils.error_exit(400, "fileMd5 should not be null")
    end
    return fileName, fileMd5
end

if ("POST" == request_method) then
    local form, err = upload:new(4096)
    if not form then
        utils.error_exit(500, err)
    end
   
    local args = nil
    local file_name = nil
    local file_size = 0
    local file_md5 = 0
    local flag = false
    local file_size_real = 0
    local md5 = resty_md5:new()
    local file = nil
    local cur_dir = pl_path.currentdir()
    if not md5 then
        utils.error_exit(400, "md5 failed")
    end
    
    while true do
        local typ, res, err = form:read()
        if not typ then
            utils.error_exit(500, "failed to read: " .. err)
        end
        if typ == "header" then
            if ("Content-Disposition" == res[1]) then
                if (nil ~= string.match(res[2], 'name="data"')) then
                    flag = true
                else
                    flag = false
                    if file_name ~= nil then
		        file_name = cur_dir.."/../"..file_name
		        file = io.open(file_name, "w+")
		        if not file then
			    utils.error_exit(500, json.encode("open file failed."..file_name))
                        end
		    end
                          
                end
            end
        elseif typ == "body" then
            if flag == true then
                args = json.decode(res)
                file_name, file_md5 = check_param(args)    
            else
		if file_name ~= nil then
                    file_size_real = file_size_real + string.len(res)
                    file:write(res)
                    md5:update(res)        
		end 
            end
        elseif typ == "part_end" then
            if flag == false and file_name ~= nil and file ~= nil then
                file:close()
                local digest = md5:final()
                local str = require "resty.string"
                local msg_ret = {}
                msg_ret["file_path"] = pl_path.abspath(file_name)
                msg_ret["file_md5"] = str.to_hex(digest)
                utils.error_exit(200, json.encode(msg_ret))
            end
        elseif typ == "eof" then
            break
        else
            -- do nothing
        end
    end

end

utils.error_exit(400, "unsupported request method")
