local json = require("json")
local utils = require("utils")
local const = require("const")
local request_method = ngx.var.request_method
local max_task_count = 30 

utils.check_login()
_, login_token = utils.check_permission("StreamCompute")

if "POST" == request_method then
    local utils_header = require("utils_header")
    local params = utils_header.check_public_boby_data()
    local name = params["Name"]
    local desc = params["Desc"]

    if name == nil or type(name) ~= "string" then
        utils.error_exit(400, "name must not be null")
    end
   
    local ok, msg_raw, err = utils.dbus_call_edge(const.stream_compute.wkn,
                                        const.stream_compute.obj,
                                        const.stream_compute.inf,
                                        const.stream_compute.method.getJobList,
                                        json.encode(cmd))

    local msg_ret = {}
    if (ok and msg_raw) then
        local ok, msg = pcall(json.decode, msg_raw[1])
        if (ok and 0 == msg["code"]) then
            local count = msg["data"]["totalCount"]
            
            if count > max_task_count then 
                utils.error_exit(400, "stream compute count already > "..max_task_count)
            end
        end	
    end 
 
    local cmd = {}

    cmd["name"] = name
    cmd["description"] = desc

    ok, msg_raw, err = utils.dbus_call_edge(const.stream_compute.wkn,
                                        const.stream_compute.obj,
                                        const.stream_compute.inf,
                                        const.stream_compute.method.newJob,
                                        json.encode(cmd))

    local msg_ret = {}
    if (ok and msg_raw) then
        local ok, msg = pcall(json.decode, msg_raw[1])
        
        msg_ret["code"] = 200
        if (ok and 0 == msg["code"]) then
            msg["TaskNo"] = msg["data"]["id"]
        end
        msg_ret["data"] = msg
        msg_ret["message"] = "success"
        
        ngx.say(json.encode(msg_ret))
        ngx.flush(true)
        ngx.exit(ngx.HTTP_OK)
    else
        utils.error_exit(500, json.encode("failed to query: "..err))
    end 
end
utils.error_exit(400, "unsupported request method")

